@@ -41,7 +41,11 @@ content_inclusion_default_libraries() {
 	package_suffix="${package#PKG_}"
 
 	local target_directory
-	target_directory=$(path_libraries)
+	## On Arch Linux and Gentoo the libraries path can change based on the package architecture.
+	target_directory=$(
+		set_current_package "$package"
+		path_libraries
+	)
 
 	content_inclusion "LIBS_${package_suffix}" "$package" "$target_directory"
 	local index files_list
