@@ -111,8 +111,15 @@ launcher_target_presence_check() {
 	local application
 	application="$1"
 
-	local application_type
+	local application_type application_type_status
 	application_type=$(application_type "$application")
+	application_type_status=$?
+	## Exit early if fetching the application type failed.
+	if [ $application_type_status -ne 0 ]; then
+		## Use exit instead of return to ensure the script execution ends here,
+		## return 1 would not stop it because this function is called through test.
+		exit 1
+	fi
 	case "$application_type" in
 		('scummvm')
 			# ScummVM games do not rely on a provided binary.
