@@ -146,6 +146,9 @@ dependency_package_providing_library_arch() {
 		('libdl.so.2')
 			package_name='glibc'
 		;;
+		('libEGL.so.1')
+			package_name='libglvnd'
+		;;
 		('libexpat.so.1')
 			package_name='expat'
 		;;
@@ -164,6 +167,9 @@ dependency_package_providing_library_arch() {
 		('libfreetype.so.6')
 			package_name='freetype2'
 		;;
+		('libfribidi.so.0')
+			package_name='fribidi'
+		;;
 		('libgcc_s.so.1')
 			package_name='gcc-libs'
 		;;
@@ -272,6 +278,9 @@ dependency_package_providing_library_arch() {
 		('libminiupnpc.so.17')
 			package_name='miniupnpc'
 		;;
+		('libminizip.so.1')
+			package_name='minizip'
+		;;
 		('libmodplug.so.1')
 			package_name='libmodplug'
 		;;
@@ -421,6 +430,9 @@ dependency_package_providing_library_arch() {
 		('libstdc++.so.6')
 			package_name='gcc-libs'
 		;;
+		('libtcmalloc_minimal.so.4')
+			package_name='gperftools'
+		;;
 		('libtheora.so.0')
 			package_name='libtheora'
 		;;
@@ -465,6 +477,9 @@ dependency_package_providing_library_arch() {
 			vulkan-icd-loader
 			vulkan-driver'
 		;;
+		('libwayland-client.so.0')
+			package_name='wayland'
+		;;
 		('libX11.so.6')
 			package_name='libx11'
 		;;
@@ -660,6 +675,9 @@ dependency_package_providing_library_arch32() {
 		('libdl.so.2')
 			package_name='lib32-glibc'
 		;;
+		('libEGL.so.1')
+			package_name='lib32-libglvnd'
+		;;
 		('libexpat.so.1')
 			package_name='lib32-expat'
 		;;
@@ -678,6 +696,9 @@ dependency_package_providing_library_arch32() {
 		('libfreetype.so.6')
 			package_name='lib32-freetype2'
 		;;
+		('libfribidi.so.0')
+			package_name='lib32-fribidi'
+		;;
 		('libgcc_s.so.1')
 			package_name='lib32-gcc-libs'
 		;;
@@ -790,6 +811,9 @@ dependency_package_providing_library_arch32() {
 			# This library is not provided in a 32-bit build for Arch Linux
 			unset package_name
 		;;
+		('libminizip.so.1')
+			package_name='lib32-minizip'
+		;;
 		('libmodplug.so.1')
 			package_name='lib32-libmodplug'
 		;;
@@ -941,6 +965,9 @@ dependency_package_providing_library_arch32() {
 		('libstdc++.so.6')
 			package_name='lib32-gcc-libs'
 		;;
+		('libtcmalloc_minimal.so.4')
+			package_name='lib32-gperftools'
+		;;
 		('libtheora.so.0')
 			package_name='lib32-libtheora'
 		;;
@@ -986,6 +1013,9 @@ dependency_package_providing_library_arch32() {
 			lib32-vulkan-icd-loader
 			lib32-vulkan-driver'
 		;;
+		('libwayland-client.so.0')
+			package_name='lib32-wayland'
+		;;
 		('libX11.so.6')
 			package_name='lib32-libx11'
 		;;
