@@ -16,6 +16,6 @@ info_package_mtree_computation() {
 			message='Creating .MTREE file for %s…\n'
 		;;
 	esac
-	print_message 'error' "$message" \
+	print_message 'info' "$message" \
 		"$package_path"
 }
