@@ -40,6 +40,10 @@ debian_dependencies_single_command() {
 
 	local package_names
 	case "$required_command" in
+		('corsix-th')
+			package_names='
+			corsix-th'
+		;;
 		('dos2unix')
 			package_names='
 			dos2unix'
@@ -76,6 +80,14 @@ debian_dependencies_single_command() {
 			package_names='
 			scummvm'
 		;;
+		('sed')
+			# The Debian policy advises against adding dependencies on packages that are part of the required set.
+			package_names=''
+		;;
+		('setxkbmap')
+			package_names='
+			x11-xkb-utils'
+		;;
 		('vcmilauncher')
 			package_names='
 			vcmi'
