@@ -205,11 +205,20 @@ gentoo_package_build_single() {
 	esac
 
 	# Run the actual package generation, using ebuild
-	local ebuild_path package_generation_return_code
+	local ebuild_path metadata_generation_return_code package_generation_return_code
 	information_package_building "$package_name"
 	mkdir --parents "${PLAYIT_WORKDIR}/portage-tmpdir"
 	ebuild_path=$(gentoo_ebuild_path "$package")
-	ebuild "$ebuild_path" manifest 1>/dev/null
+	{
+		ebuild "$ebuild_path" manifest 1>/dev/null
+		metadata_generation_return_code=$?
+	} || true
+
+	if [ $metadata_generation_return_code -ne 0 ]; then
+		error_package_metadata_generation_failed "$package_name"
+		return 1
+	fi
+
 	## The following variables must be exported, otherwise ebuild would not pick them up.
 	PORTAGE_TMPDIR="${PLAYIT_WORKDIR}/portage-tmpdir"
 	PKGDIR="${PLAYIT_WORKDIR}/gentoo-pkgdir"
