@@ -40,6 +40,10 @@ gentoo_dependencies_single_command() {
 
 	local package_names
 	case "$required_command" in
+		('corsix-th')
+			package_names='
+			games-simulation/corsix-th'
+		;;
 		('dos2unix')
 			package_names='
 			app-text/dos2unix'
@@ -76,6 +80,14 @@ gentoo_dependencies_single_command() {
 			package_names='
 			games-engines/scummvm'
 		;;
+		('sed')
+			package_names='
+			sys-apps/sed'
+		;;
+		('setxkbmap')
+			package_names='
+			x11-apps/setxkbmap'
+		;;
 		('vcmilauncher')
 			dependency_gentoo_overlays_add 'https://cgit.gentoo.org/proj/gamerlay.git'
 			package_names='
