@@ -159,6 +159,9 @@ dependency_package_providing_library_gentoo() {
 		('libdl.so.2')
 			package_name='sys-libs/glibc'
 		;;
+		('libEGL.so.1')
+			package_name='media-libs/libglvnd'
+		;;
 		('libexpat.so.1')
 			package_name='dev-libs/expat'
 		;;
@@ -179,6 +182,9 @@ dependency_package_providing_library_gentoo() {
 		('libfreetype.so.6')
 			package_name='media-libs/freetype'
 		;;
+		('libfribidi.so.0')
+			package_name='dev-libs/fribidi'
+		;;
 		('libgcc_s.so.1')
 			package_name='sys-devel/gcc'
 		;;
@@ -289,6 +295,9 @@ dependency_package_providing_library_gentoo() {
 		('libminiupnpc.so.17')
 			package_name='net-libs/miniupnpc'
 		;;
+		('libminizip.so.1')
+			package_name='sys-libs/zlib'
+		;;
 		('libmodplug.so.1')
 			package_name='media-libs/libmodplug'
 		;;
@@ -442,6 +451,9 @@ dependency_package_providing_library_gentoo() {
 		('libstdc++.so.6')
 			package_name='sys-devel/gcc'
 		;;
+		('libtcmalloc_minimal.so.4')
+			package_name='dev-util/google-perftools'
+		;;
 		('libtheora.so.0')
 			package_name='media-libs/libtheora'
 		;;
@@ -484,6 +496,9 @@ dependency_package_providing_library_gentoo() {
 		('libvulkan.so.1')
 			package_name='media-libs/vulkan-loader'
 		;;
+		('libwayland-client.so.0')
+			package_name='dev-libs/wayland'
+		;;
 		('libX11.so.6')
 			package_name='x11-libs/libX11'
 		;;
@@ -684,6 +699,9 @@ dependency_package_providing_library_gentoo32() {
 		('libdl.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
+		('libEGL.so.1')
+			package_name='media-libs/libglvnd[abi_x86_32]'
+		;;
 		('libexpat.so.1')
 			package_name='dev-libs/expat[abi_x86_32]'
 		;;
@@ -704,6 +722,9 @@ dependency_package_providing_library_gentoo32() {
 		('libfreetype.so.6')
 			package_name='media-libs/freetype[abi_x86_32]'
 		;;
+		('libfribidi.so.0')
+			package_name='dev-libs/fribidi[abi_x86_32]'
+		;;
 		('libgcc_s.so.1')
 			package_name='sys-devel/gcc[abi_x86_32]'
 		;;
@@ -814,6 +835,9 @@ dependency_package_providing_library_gentoo32() {
 		('libminiupnpc.so.17')
 			package_name='net-libs/miniupnpc[abi_x86_32]'
 		;;
+		('libminizip.so.1')
+			package_name='sys-libs/zlib[abi_x86_32]'
+		;;
 		('libmodplug.so.1')
 			package_name='media-libs/libmodplug[abi_x86_32]'
 		;;
@@ -967,6 +991,9 @@ dependency_package_providing_library_gentoo32() {
 		('libstdc++.so.6')
 			package_name='sys-devel/gcc amd64? ( sys-devel/gcc[multilib] )'
 		;;
+		('libtcmalloc_minimal.so.4')
+			package_name='dev-util/google-perftools[abi_x86_32]'
+		;;
 		('libtheora.so.0')
 			package_name='media-libs/libtheora[abi_x86_32]'
 		;;
@@ -1009,6 +1036,9 @@ dependency_package_providing_library_gentoo32() {
 		('libvulkan.so.1')
 			package_name='media-libs/vulkan-loader[abi_x86_32]'
 		;;
+		('libwayland-client.so.0')
+			package_name='dev-libs/wayland[abi_x86_32]'
+		;;
 		('libX11.so.6')
 			package_name='x11-libs/libX11[abi_x86_32]'
 		;;
